@@ -115,9 +115,9 @@ test_that("print.control", {
 
   co <- control.icm(type = "SI", nsteps = 10)
   expect_output(print(co), "ICM Control Settings")
-  expect_output(print(co), "Built-In Modules: initialize.FUN")
+  expect_output(print(co), "Integrated Modules: initialize.FUN")
 
   co <- control.net(type = "SI", nsteps = 10)
   expect_output(print(co), "Network Model Control Settings")
-  expect_output(print(co), "Built-In Modules: initialize.FUN")
+  expect_output(print(co), "Integrated Modules: initialize.FUN")
 })
